/***************************************************************************
 *   Copyright (C) 2010 by Martin Burgemeister, Mathis Lindemann           *
 *     																	   *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#ifndef LUASEARCH_H_
#define LUASEARCH_H_
extern "C" {
#include <lua.h>
#include <lualib.h>
#include <lauxlib.h>
}
#include "lua/Luna.h"
#include "controller/SearchController.h"
#include "lua/LuaWrapper.h"

/**
 * \class LuaSearch
 * \brief Wrapper class for SearchController.
 *
 * This class wraps the SearchController methods to use them in Lua. All
 * methods, which will be used in Lua, have a lua_State as an argument.
 * It is needed for the communication between C and Lua. All required methods
 * have to be registered.
 *
 * \author Martin Burgemeister <Martin.Burgemeister@gmx.de>,
 *         Mathis Lindemann <MathisLindemann@gmx.net>
 * \version 1.0
 * \date 16 August 2010
 * \see SearchController
 */
class LuaSearch : public LuaWrapper
{
public:
    LuaSearch ( lua_State* );
    ~LuaSearch ();

    int search      ( lua_State* );
    int searchTable ( lua_State* );

    int next         ( lua_State* );
    int previous     ( lua_State* );
    int selectAll    ( lua_State* = 0 );
    int numberOfHits ( lua_State* );

    int addItems    ( lua_State* );

    int hasNext     ( lua_State* );
    int hasPrevious ( lua_State* );


    /**
     * \brief Class name for Luna (see Luna.h)
     */
    static const char className[];
    /**
     * \brief Register of the functions.
     *
     * A RegType of all functions which will be used in Lua.
     */
    static const Luna<LuaSearch>::RegType Register[];
private:
    /**
     * \brief Search controller object.
     */
    SearchController* searchControl_;
};

#endif /* LUASEARCH_H_ */
